==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/PoetryPyproject.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Represents configuration of a pyproject.toml file for a Poetry project.
 * <p>
 * @see https://python-poetry.org/docs/pyproject/
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.896Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.PoetryPyproject")
public class PoetryPyproject extends io.github.cdklabs.projen.Component {

    protected PoetryPyproject(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PoetryPyproject(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PoetryPyproject(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PoetryPyprojectOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.TomlFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TomlFile.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.PoetryPyproject}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.PoetryPyproject> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.python.PythonProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.python.PythonProject project;
        private final io.github.cdklabs.projen.python.PoetryPyprojectOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.python.PythonProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.python.PoetryPyprojectOptions.Builder();
        }

        /**
         * (experimental) The authors of the package.
         * <p>
         * Must be in the form "name <email>"
         * <p>
         * @return {@code this}
         * @param authors The authors of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authors(final java.util.List<java.lang.String> authors) {
            this.options.authors(authors);
            return this;
        }

        /**
         * (experimental) A list of PyPI trove classifiers that describe the project.
         * <p>
         * @return {@code this}
         * @see https://pypi.org/classifiers/
         * @param classifiers A list of PyPI trove classifiers that describe the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder classifiers(final java.util.List<java.lang.String> classifiers) {
            this.options.classifiers(classifiers);
            return this;
        }

        /**
         * (experimental) A short description of the package (required).
         * <p>
         * @return {@code this}
         * @param description A short description of the package (required). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.options.description(description);
            return this;
        }

        /**
         * (experimental) A URL to the documentation of the project.
         * <p>
         * @return {@code this}
         * @param documentation A URL to the documentation of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder documentation(final java.lang.String documentation) {
            this.options.documentation(documentation);
            return this;
        }

        /**
         * (experimental) A list of patterns that will be excluded in the final package.
         * <p>
         * If a VCS is being used for a package, the exclude field will be seeded with
         * the VCS’ ignore settings (.gitignore for git for example).
         * <p>
         * @return {@code this}
         * @param exclude A list of patterns that will be excluded in the final package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(final java.util.List<java.lang.String> exclude) {
            this.options.exclude(exclude);
            return this;
        }

        /**
         * (experimental) Package extras.
         * <p>
         * @return {@code this}
         * @param extras Package extras. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder extras(final java.util.Map<java.lang.String, ? extends java.util.List<java.lang.String>> extras) {
            this.options.extras(extras);
            return this;
        }

        /**
         * (experimental) A URL to the website of the project.
         * <p>
         * @return {@code this}
         * @param homepage A URL to the website of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder homepage(final java.lang.String homepage) {
            this.options.homepage(homepage);
            return this;
        }

        /**
         * (experimental) A list of patterns that will be included in the final package.
         * <p>
         * @return {@code this}
         * @param include A list of patterns that will be included in the final package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(final java.util.List<java.lang.String> include) {
            this.options.include(include);
            return this;
        }

        /**
         * (experimental) A list of keywords (max: 5) that the package is related to.
         * <p>
         * @return {@code this}
         * @param keywords A list of keywords (max: 5) that the package is related to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder keywords(final java.util.List<java.lang.String> keywords) {
            this.options.keywords(keywords);
            return this;
        }

        /**
         * (experimental) License of this package as an SPDX identifier.
         * <p>
         * If the project is proprietary and does not use a specific license, you
         * can set this value as "Proprietary".
         * <p>
         * @return {@code this}
         * @param license License of this package as an SPDX identifier. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder license(final java.lang.String license) {
            this.options.license(license);
            return this;
        }

        /**
         * (experimental) the maintainers of the package.
         * <p>
         * Must be in the form "name <email>"
         * <p>
         * @return {@code this}
         * @param maintainers the maintainers of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder maintainers(final java.util.List<java.lang.String> maintainers) {
            this.options.maintainers(maintainers);
            return this;
        }

        /**
         * (experimental) Name of the package (required).
         * <p>
         * @return {@code this}
         * @param name Name of the package (required). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.options.name(name);
            return this;
        }

        /**
         * (experimental) A list of packages and modules to include in the final distribution.
         * <p>
         * @return {@code this}
         * @param packages A list of packages and modules to include in the final distribution. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packages(final java.util.List<? extends java.lang.Object> packages) {
            this.options.packages(packages);
            return this;
        }

        /**
         * (experimental) Plugins.
         * <p>
         * Must be specified as a table.
         * <p>
         * @return {@code this}
         * @see https://toml.io/en/v1.0.0#table
         * @param plugins Plugins. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder plugins(final java.lang.Object plugins) {
            this.options.plugins(plugins);
            return this;
        }

        /**
         * (experimental) The name of the readme file of the package.
         * <p>
         * @return {@code this}
         * @param readme The name of the readme file of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readme(final java.lang.String readme) {
            this.options.readme(readme);
            return this;
        }

        /**
         * (experimental) A URL to the repository of the project.
         * <p>
         * @return {@code this}
         * @param repository A URL to the repository of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder repository(final java.lang.String repository) {
            this.options.repository(repository);
            return this;
        }

        /**
         * (experimental) The scripts or executables that will be installed when installing the package.
         * <p>
         * @return {@code this}
         * @param scripts The scripts or executables that will be installed when installing the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder scripts(final java.util.Map<java.lang.String, ? extends java.lang.Object> scripts) {
            this.options.scripts(scripts);
            return this;
        }

        /**
         * (experimental) Source registries from which packages are retrieved.
         * <p>
         * @return {@code this}
         * @param source Source registries from which packages are retrieved. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder source(final java.util.List<? extends java.lang.Object> source) {
            this.options.source(source);
            return this;
        }

        /**
         * (experimental) Project custom URLs, in addition to homepage, repository and documentation.
         * <p>
         * E.g. "Bug Tracker"
         * <p>
         * @return {@code this}
         * @param urls Project custom URLs, in addition to homepage, repository and documentation. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder urls(final java.util.Map<java.lang.String, java.lang.String> urls) {
            this.options.urls(urls);
            return this;
        }

        /**
         * (experimental) Version of the package (required).
         * <p>
         * @return {@code this}
         * @param version Version of the package (required). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * (experimental) A list of dependencies for the project.
         * <p>
         * The python version for which your package is compatible is also required.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated from non-compiling source. May contain errors.
         * { requests: "^2.13.0" }
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param dependencies A list of dependencies for the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dependencies(final java.util.Map<java.lang.String, ? extends java.lang.Object> dependencies) {
            this.options.dependencies(dependencies);
            return this;
        }

        /**
         * (experimental) A list of development dependencies for the project.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated from non-compiling source. May contain errors.
         * { requests: "^2.13.0" }
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param devDependencies A list of development dependencies for the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder devDependencies(final java.util.Map<java.lang.String, ? extends java.lang.Object> devDependencies) {
            this.options.devDependencies(devDependencies);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.python.PoetryPyproject}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.PoetryPyproject build() {
            return new io.github.cdklabs.projen.python.PoetryPyproject(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/PoetryPyproject.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Represents configuration of a pyproject.toml file for a Poetry project.
 * <p>
 * @see <a href="https://python-poetry.org/docs/pyproject/">https://python-poetry.org/docs/pyproject/</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.568Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.PoetryPyproject")
public class PoetryPyproject extends io.github.cdklabs.projen.Component {

    protected PoetryPyproject(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PoetryPyproject(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PoetryPyproject(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PoetryPyprojectOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.TomlFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TomlFile.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.PoetryPyproject}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.PoetryPyproject> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.python.PoetryPyprojectOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.python.PoetryPyprojectOptions.Builder();
        }

        /**
         * (experimental) The authors of the package.
         * <p>
         * Must be in the form "name <email>"
         * <p>
         * @return {@code this}
         * @param authors The authors of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authors(final java.util.List<java.lang.String> authors) {
            this.options.authors(authors);
            return this;
        }

        /**
         * (experimental) A list of PyPI trove classifiers that describe the project.
         * <p>
         * @return {@code this}
         * @see <a href="https://pypi.org/classifiers/">https://pypi.org/classifiers/</a>
         * @param classifiers A list of PyPI trove classifiers that describe the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder classifiers(final java.util.List<java.lang.String> classifiers) {
            this.options.classifiers(classifiers);
            return this;
        }

        /**
         * (experimental) A short description of the package (required).
         * <p>
         * @return {@code this}
         * @param description A short description of the package (required). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.options.description(description);
            return this;
        }

        /**
         * (experimental) A URL to the documentation of the project.
         * <p>
         * @return {@code this}
         * @param documentation A URL to the documentation of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder documentation(final java.lang.String documentation) {
            this.options.documentation(documentation);
            return this;
        }

        /**
         * (experimental) A list of patterns that will be excluded in the final package.
         * <p>
         * If a VCS is being used for a package, the exclude field will be seeded with
         * the VCS’ ignore settings (.gitignore for git for example).
         * <p>
         * @return {@code this}
         * @param exclude A list of patterns that will be excluded in the final package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(final java.util.List<java.lang.String> exclude) {
            this.options.exclude(exclude);
            return this;
        }

        /**
         * (experimental) Package extras.
         * <p>
         * @return {@code this}
         * @param extras Package extras. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder extras(final java.util.Map<java.lang.String, ? extends java.util.List<java.lang.String>> extras) {
            this.options.extras(extras);
            return this;
        }

        /**
         * (experimental) A URL to the website of the project.
         * <p>
         * @return {@code this}
         * @param homepage A URL to the website of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder homepage(final java.lang.String homepage) {
            this.options.homepage(homepage);
            return this;
        }

        /**
         * (experimental) A list of patterns that will be included in the final package.
         * <p>
         * @return {@code this}
         * @param include A list of patterns that will be included in the final package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(final java.util.List<java.lang.String> include) {
            this.options.include(include);
            return this;
        }

        /**
         * (experimental) A list of keywords (max: 5) that the package is related to.
         * <p>
         * @return {@code this}
         * @param keywords A list of keywords (max: 5) that the package is related to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder keywords(final java.util.List<java.lang.String> keywords) {
            this.options.keywords(keywords);
            return this;
        }

        /**
         * (experimental) License of this package as an SPDX identifier.
         * <p>
         * If the project is proprietary and does not use a specific license, you
         * can set this value as "Proprietary".
         * <p>
         * @return {@code this}
         * @param license License of this package as an SPDX identifier. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder license(final java.lang.String license) {
            this.options.license(license);
            return this;
        }

        /**
         * (experimental) the maintainers of the package.
         * <p>
         * Must be in the form "name <email>"
         * <p>
         * @return {@code this}
         * @param maintainers the maintainers of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder maintainers(final java.util.List<java.lang.String> maintainers) {
            this.options.maintainers(maintainers);
            return this;
        }

        /**
         * (experimental) Name of the package (required).
         * <p>
         * @return {@code this}
         * @param name Name of the package (required). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.options.name(name);
            return this;
        }

        /**
         * (experimental) A list of packages and modules to include in the final distribution.
         * <p>
         * @return {@code this}
         * @param packages A list of packages and modules to include in the final distribution. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packages(final java.util.List<? extends java.lang.Object> packages) {
            this.options.packages(packages);
            return this;
        }

        /**
         * (experimental) Plugins.
         * <p>
         * Must be specified as a table.
         * <p>
         * @return {@code this}
         * @see <a href="https://toml.io/en/v1.0.0#table">https://toml.io/en/v1.0.0#table</a>
         * @param plugins Plugins. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder plugins(final java.lang.Object plugins) {
            this.options.plugins(plugins);
            return this;
        }

        /**
         * (experimental) The name of the readme file of the package.
         * <p>
         * @return {@code this}
         * @param readme The name of the readme file of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readme(final java.lang.String readme) {
            this.options.readme(readme);
            return this;
        }

        /**
         * (experimental) A URL to the repository of the project.
         * <p>
         * @return {@code this}
         * @param repository A URL to the repository of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder repository(final java.lang.String repository) {
            this.options.repository(repository);
            return this;
        }

        /**
         * (experimental) The scripts or executables that will be installed when installing the package.
         * <p>
         * @return {@code this}
         * @param scripts The scripts or executables that will be installed when installing the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder scripts(final java.util.Map<java.lang.String, ? extends java.lang.Object> scripts) {
            this.options.scripts(scripts);
            return this;
        }

        /**
         * (experimental) Source registries from which packages are retrieved.
         * <p>
         * @return {@code this}
         * @param source Source registries from which packages are retrieved. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder source(final java.util.List<? extends java.lang.Object> source) {
            this.options.source(source);
            return this;
        }

        /**
         * (experimental) Project custom URLs, in addition to homepage, repository and documentation.
         * <p>
         * E.g. "Bug Tracker"
         * <p>
         * @return {@code this}
         * @param urls Project custom URLs, in addition to homepage, repository and documentation. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder urls(final java.util.Map<java.lang.String, java.lang.String> urls) {
            this.options.urls(urls);
            return this;
        }

        /**
         * (experimental) Version of the package (required).
         * <p>
         * @return {@code this}
         * @param version Version of the package (required). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * (experimental) A list of dependencies for the project.
         * <p>
         * The python version for which your package is compatible is also required.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * { requests: "^2.13.0" }
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param dependencies A list of dependencies for the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dependencies(final java.util.Map<java.lang.String, ? extends java.lang.Object> dependencies) {
            this.options.dependencies(dependencies);
            return this;
        }

        /**
         * (experimental) A list of development dependencies for the project.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * { requests: "^2.13.0" }
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param devDependencies A list of development dependencies for the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder devDependencies(final java.util.Map<java.lang.String, ? extends java.lang.Object> devDependencies) {
            this.options.devDependencies(devDependencies);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.python.PoetryPyproject}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.PoetryPyproject build() {
            return new io.github.cdklabs.projen.python.PoetryPyproject(
                this.project,
                this.options.build()
            );
        }
    }
}
